import grpc


from .gen.admin.v1.audit_pb2 import (
	GetLogsRequest,
	GetLogByIDRequest,
	GetLogsResponse,
	GetLogByIDResponse,
	GetEventBySessionRequest,
	GetEventBySessionResponse,
	EventData,
	GetDataBySessionRequest,
	SshData,
	GetDataBySessionResponse,
)

from .gen.admin.v1.audit_pb2_grpc import AuditLogsServiceStub
class AuditLogsService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = AuditLogsServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def GetLogs(self, request: GetLogsRequest) -> GetLogsResponse:
		return self.stub.GetLogs(request, metadata=self.headers)

	def GetLogByID(self, request: GetLogByIDRequest) -> GetLogByIDResponse:
		return self.stub.GetLogByID(request, metadata=self.headers)

	def GetEventBySession(self, request: GetEventBySessionRequest) -> GetEventBySessionResponse:
		return self.stub.GetEventBySession(request, metadata=self.headers)

	def GetDataBySession(self, request: GetDataBySessionRequest) -> GetDataBySessionResponse:
		return self.stub.GetDataBySession(request, metadata=self.headers)




import grpc


from .gen.admin.v1.integration_code_repository_pb2 import (
	DeleteCodeRepoByIdRequest,
	DeleteCodeRepoByIdResponse,
	CancelDeleteCodeRepoByIdRequest,
	CancelDeleteCodeRepoByIdResponse,
	ConnectCodeRepositoryRequest,
	ConnectCodeRepositoryResponse,
	GetAccessTokenRequest,
	GetAccessTokenResponse,
	GetGithubRepositoriesFromAuthUserRequest,
	GetGithubRepositoriesFromAuthUserResponse,
	GetUserAccessTokenRequest,
	GetUserAccessTokenResponse,
	GetCodeReposRequest,
	GetCodeReposResponse,
	CreateCodeRepoRequest,
	CreateCodeRepoResponse,
)

from .gen.admin.v1.integration_code_repository_pb2_grpc import CodeRepositoryServiceStub
class CodeRepositoryService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = CodeRepositoryServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def DeleteCodeRepoById(self, request: DeleteCodeRepoByIdRequest) -> DeleteCodeRepoByIdResponse:
		return self.stub.DeleteCodeRepoById(request, metadata=self.headers)

	def CancelDeleteCodeRepoById(self, request: CancelDeleteCodeRepoByIdRequest) -> CancelDeleteCodeRepoByIdResponse:
		return self.stub.CancelDeleteCodeRepoById(request, metadata=self.headers)

	def ConnectCodeRepository(self, request: ConnectCodeRepositoryRequest) -> ConnectCodeRepositoryResponse:
		return self.stub.ConnectCodeRepository(request, metadata=self.headers)

	def GetAccessToken(self, request: GetAccessTokenRequest) -> GetAccessTokenResponse:
		return self.stub.GetAccessToken(request, metadata=self.headers)

	def GetGithubRepositoriesFromAuthUser(self, request: GetGithubRepositoriesFromAuthUserRequest) -> GetGithubRepositoriesFromAuthUserResponse:
		return self.stub.GetGithubRepositoriesFromAuthUser(request, metadata=self.headers)

	def GetUserAccessToken(self, request: GetUserAccessTokenRequest) -> GetUserAccessTokenResponse:
		return self.stub.GetUserAccessToken(request, metadata=self.headers)

	def GetCodeRepos(self, request: GetCodeReposRequest) -> GetCodeReposResponse:
		return self.stub.GetCodeRepos(request, metadata=self.headers)

	def CreateCodeRepo(self, request: CreateCodeRepoRequest) -> CreateCodeRepoResponse:
		return self.stub.CreateCodeRepo(request, metadata=self.headers)




from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GithubRepository(_message.Message):
    __slots__ = ["id", "full_name", "html_url"]
    ID_FIELD_NUMBER: _ClassVar[int]
    FULL_NAME_FIELD_NUMBER: _ClassVar[int]
    HTML_URL_FIELD_NUMBER: _ClassVar[int]
    id: int
    full_name: str
    html_url: str
    def __init__(self, id: _Optional[int] = ..., full_name: _Optional[str] = ..., html_url: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/admin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2
from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61\x64min/v1/admin.proto\x12\x08\x61\x64min.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avalidate/v1/validate.proto\x1a%admin/v1/types/v1/list_metadata.proto\"m\n\x11GetApiKeysRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x14\n\x05\x61\x66ter\x18\x02 \x01(\tR\x05\x61\x66ter\x12\x16\n\x06\x62\x65\x66ore\x18\x03 \x01(\tR\x06\x62\x65\x66ore\x12\x14\n\x05order\x18\x04 \x01(\tR\x05order\"y\n\x06\x41piKey\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12\x39\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"\x87\x01\n\x12GetApiKeysResponse\x12+\n\x08\x61pi_keys\x18\x01 \x03(\x0b\x32\x10.admin.v1.ApiKeyR\x07\x61piKeys\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"2\n\x13\x43reateApiKeyRequest\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\"\xa8\x01\n\x14\x43reateApiKeyResponse\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12\x1f\n\x06secret\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06secret\x12\x39\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\".\n\x13\x44\x65leteApiKeyRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"\x16\n\x14\x44\x65leteApiKeyResponse2\xf9\x01\n\nDevService\x12I\n\nGetApiKeys\x12\x1b.admin.v1.GetApiKeysRequest\x1a\x1c.admin.v1.GetApiKeysResponse\"\x00\x12O\n\x0c\x43reateApiKey\x12\x1d.admin.v1.CreateApiKeyRequest\x1a\x1e.admin.v1.CreateApiKeyResponse\"\x00\x12O\n\x0c\x44\x65leteApiKey\x12\x1d.admin.v1.DeleteApiKeyRequest\x1a\x1e.admin.v1.DeleteApiKeyResponse\"\x00\x42\xa5\x01\n\x0c\x63om.admin.v1B\nAdminProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.admin_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\nAdminProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_APIKEY'].fields_by_name['id']._options = None
  _globals['_APIKEY'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_APIKEY'].fields_by_name['name']._options = None
  _globals['_APIKEY'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEAPIKEYREQUEST'].fields_by_name['name']._options = None
  _globals['_CREATEAPIKEYREQUEST'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEAPIKEYRESPONSE'].fields_by_name['id']._options = None
  _globals['_CREATEAPIKEYRESPONSE'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEAPIKEYRESPONSE'].fields_by_name['name']._options = None
  _globals['_CREATEAPIKEYRESPONSE'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEAPIKEYRESPONSE'].fields_by_name['secret']._options = None
  _globals['_CREATEAPIKEYRESPONSE'].fields_by_name['secret']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DELETEAPIKEYREQUEST'].fields_by_name['id']._options = None
  _globals['_DELETEAPIKEYREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETAPIKEYSREQUEST']._serialized_start=134
  _globals['_GETAPIKEYSREQUEST']._serialized_end=243
  _globals['_APIKEY']._serialized_start=245
  _globals['_APIKEY']._serialized_end=366
  _globals['_GETAPIKEYSRESPONSE']._serialized_start=369
  _globals['_GETAPIKEYSRESPONSE']._serialized_end=504
  _globals['_CREATEAPIKEYREQUEST']._serialized_start=506
  _globals['_CREATEAPIKEYREQUEST']._serialized_end=556
  _globals['_CREATEAPIKEYRESPONSE']._serialized_start=559
  _globals['_CREATEAPIKEYRESPONSE']._serialized_end=727
  _globals['_DELETEAPIKEYREQUEST']._serialized_start=729
  _globals['_DELETEAPIKEYREQUEST']._serialized_end=775
  _globals['_DELETEAPIKEYRESPONSE']._serialized_start=777
  _globals['_DELETEAPIKEYRESPONSE']._serialized_end=799
  _globals['_DEVSERVICE']._serialized_start=802
  _globals['_DEVSERVICE']._serialized_end=1051
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/types/v1/coderepo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n admin/v1/types/v1/coderepo.proto\x12\x11\x61\x64min.v1.types.v1\"\xba\x02\n\x08\x43odeRepo\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x33\n\x16\x63loud_provider_repo_id\x18\x02 \x01(\x05R\x13\x63loudProviderRepoId\x12\x1d\n\ncreated_by\x18\x03 \x01(\tR\tcreatedBy\x12\x12\n\x04type\x18\x04 \x01(\tR\x04type\x12\x12\n\x04name\x18\x05 \x01(\tR\x04name\x12\x17\n\x07hook_id\x18\x06 \x01(\x05R\x06hookId\x12\x16\n\x06status\x18\x07 \x01(\tR\x06status\x12\x16\n\x06\x61\x63tive\x18\x08 \x01(\x08R\x06\x61\x63tive\x12\x1d\n\ncreated_at\x18\t \x01(\tR\tcreatedAt\x12\x1d\n\nupdated_at\x18\n \x01(\tR\tupdatedAt\x12\x1b\n\texpire_at\x18\x0b \x01(\tR\x08\x65xpireAtB\xe0\x01\n\x15\x63om.admin.v1.types.v1B\rCoderepoProtoP\x01ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.coderepo_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\rCoderepoProtoP\001ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_CODEREPO']._serialized_start=56
  _globals['_CODEREPO']._serialized_end=370
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from ...validate.v1 import validate_pb2 as _validate_pb2
from .types.v1 import list_metadata_pb2 as _list_metadata_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetApiKeysRequest(_message.Message):
    __slots__ = ["limit", "after", "before", "order"]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    limit: int
    after: str
    before: str
    order: str
    def __init__(self, limit: _Optional[int] = ..., after: _Optional[str] = ..., before: _Optional[str] = ..., order: _Optional[str] = ...) -> None: ...

class ApiKey(_message.Message):
    __slots__ = ["id", "name", "created_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GetApiKeysResponse(_message.Message):
    __slots__ = ["api_keys", "list_metadata"]
    API_KEYS_FIELD_NUMBER: _ClassVar[int]
    LIST_METADATA_FIELD_NUMBER: _ClassVar[int]
    api_keys: _containers.RepeatedCompositeFieldContainer[ApiKey]
    list_metadata: _list_metadata_pb2.ListMetadata
    def __init__(self, api_keys: _Optional[_Iterable[_Union[ApiKey, _Mapping]]] = ..., list_metadata: _Optional[_Union[_list_metadata_pb2.ListMetadata, _Mapping]] = ...) -> None: ...

class CreateApiKeyRequest(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreateApiKeyResponse(_message.Message):
    __slots__ = ["id", "name", "secret", "created_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    secret: str
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., secret: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class DeleteApiKeyRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteApiKeyResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_datahub_pb2 as admin_dot_v1_dot_integration__datahub__pb2


class DatahubServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateDatahubIntegration = channel.unary_unary(
                '/admin.v1.DatahubService/CreateDatahubIntegration',
                request_serializer=admin_dot_v1_dot_integration__datahub__pb2.CreateDatahubIntegrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__datahub__pb2.CreateDatahubIntegrationResponse.FromString,
                )
        self.GetDatahubIntegration = channel.unary_unary(
                '/admin.v1.DatahubService/GetDatahubIntegration',
                request_serializer=admin_dot_v1_dot_integration__datahub__pb2.GetDatahubIntegrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__datahub__pb2.GetDatahubIntegrationResponse.FromString,
                )
        self.UpdateDatahubIntegration = channel.unary_unary(
                '/admin.v1.DatahubService/UpdateDatahubIntegration',
                request_serializer=admin_dot_v1_dot_integration__datahub__pb2.UpdateDatahubIntegrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__datahub__pb2.UpdateDatahubIntegrationResponse.FromString,
                )
        self.RefreshWebhookToken = channel.unary_unary(
                '/admin.v1.DatahubService/RefreshWebhookToken',
                request_serializer=admin_dot_v1_dot_integration__datahub__pb2.RefreshWebhookTokenRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__datahub__pb2.RefreshWebhookTokenResponse.FromString,
                )
        self.DeleteDatahubIntegration = channel.unary_unary(
                '/admin.v1.DatahubService/DeleteDatahubIntegration',
                request_serializer=admin_dot_v1_dot_integration__datahub__pb2.DeleteDatahubIntegrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__datahub__pb2.DeleteDatahubIntegrationResponse.FromString,
                )


class DatahubServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateDatahubIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatahubIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDatahubIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RefreshWebhookToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDatahubIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DatahubServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateDatahubIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDatahubIntegration,
                    request_deserializer=admin_dot_v1_dot_integration__datahub__pb2.CreateDatahubIntegrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__datahub__pb2.CreateDatahubIntegrationResponse.SerializeToString,
            ),
            'GetDatahubIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatahubIntegration,
                    request_deserializer=admin_dot_v1_dot_integration__datahub__pb2.GetDatahubIntegrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__datahub__pb2.GetDatahubIntegrationResponse.SerializeToString,
            ),
            'UpdateDatahubIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDatahubIntegration,
                    request_deserializer=admin_dot_v1_dot_integration__datahub__pb2.UpdateDatahubIntegrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__datahub__pb2.UpdateDatahubIntegrationResponse.SerializeToString,
            ),
            'RefreshWebhookToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RefreshWebhookToken,
                    request_deserializer=admin_dot_v1_dot_integration__datahub__pb2.RefreshWebhookTokenRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__datahub__pb2.RefreshWebhookTokenResponse.SerializeToString,
            ),
            'DeleteDatahubIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDatahubIntegration,
                    request_deserializer=admin_dot_v1_dot_integration__datahub__pb2.DeleteDatahubIntegrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__datahub__pb2.DeleteDatahubIntegrationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.DatahubService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DatahubService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateDatahubIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DatahubService/CreateDatahubIntegration',
            admin_dot_v1_dot_integration__datahub__pb2.CreateDatahubIntegrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__datahub__pb2.CreateDatahubIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDatahubIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DatahubService/GetDatahubIntegration',
            admin_dot_v1_dot_integration__datahub__pb2.GetDatahubIntegrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__datahub__pb2.GetDatahubIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDatahubIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DatahubService/UpdateDatahubIntegration',
            admin_dot_v1_dot_integration__datahub__pb2.UpdateDatahubIntegrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__datahub__pb2.UpdateDatahubIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RefreshWebhookToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DatahubService/RefreshWebhookToken',
            admin_dot_v1_dot_integration__datahub__pb2.RefreshWebhookTokenRequest.SerializeToString,
            admin_dot_v1_dot_integration__datahub__pb2.RefreshWebhookTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDatahubIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DatahubService/DeleteDatahubIntegration',
            admin_dot_v1_dot_integration__datahub__pb2.DeleteDatahubIntegrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__datahub__pb2.DeleteDatahubIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import grpc


from .gen.admin.v1.integration_kms_pb2 import (
	CreateKeyRegistrationRequest,
	CreateKeyRegistrationResponse,
	GetKeysRequest,
	GetKeysResponse,
	GetKeyRequest,
	GetKeyResponse,
	DeactivateFieldEncryptionKeyRequest,
	DeactivateFieldEncryptionKeyResponse,
)

from .gen.admin.v1.integration_kms_pb2_grpc import KmsServiceStub
class KmsService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = KmsServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def CreateKeyRegistration(self, request: CreateKeyRegistrationRequest) -> CreateKeyRegistrationResponse:
		return self.stub.CreateKeyRegistration(request, metadata=self.headers)

	def GetKeys(self, request: GetKeysRequest) -> GetKeysResponse:
		return self.stub.GetKeys(request, metadata=self.headers)

	def GetKey(self, request: GetKeyRequest) -> GetKeyResponse:
		return self.stub.GetKey(request, metadata=self.headers)

	def DeactivateFieldEncryptionKey(self, request: DeactivateFieldEncryptionKeyRequest) -> DeactivateFieldEncryptionKeyResponse:
		return self.stub.DeactivateFieldEncryptionKey(request, metadata=self.headers)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/inventory.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import domain_pb2 as admin_dot_v1_dot_types_dot_v1_dot_domain__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2
from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61\x64min/v1/inventory.proto\x12\x08\x61\x64min.v1\x1a\x1e\x61\x64min/v1/types/v1/domain.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avalidate/v1/validate.proto\x1a%admin/v1/types/v1/list_metadata.proto\"\x1c\n\x1aGetInventoryFlatOldRequest\"\xa6\x04\n\tColumnOld\x12\x1d\n\ncreated_at\x18\x01 \x01(\x03R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x02 \x01(\x03R\tupdatedAt\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x04 \x01(\tR\rdatastoreName\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\x12*\n\x11table_physical_id\x18\x06 \x01(\tR\x0ftablePhysicalId\x12\x34\n\x16table_attribute_number\x18\x07 \x01(\x04R\x14tableAttributeNumber\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x14\n\x05\x61lias\x18\t \x01(\tR\x05\x61lias\x12\x1d\n\ntable_path\x18\n \x01(\tR\ttablePath\x12\x1d\n\ndata_label\x18\x0b \x01(\tR\tdataLabel\x12\x1b\n\tdata_type\x18\x0c \x01(\tR\x08\x64\x61taType\x12\"\n\rdata_type_oid\x18\r \x01(\rR\x0b\x64\x61taTypeOid\x12@\n\x1d\x64\x61ta_label_locked_for_sidecar\x18\x0e \x01(\x08R\x19\x64\x61taLabelLockedForSidecar\x12\x12\n\x04tags\x18\x0f \x03(\tR\x04tags\x12\x1c\n\tencrypted\x18\x10 \x01(\x08R\tencrypted\"P\n\x1bGetInventoryFlatOldResponse\x12\x31\n\tinventory\x18\x01 \x03(\x0b\x32\x13.admin.v1.ColumnOldR\tinventory\"\x94\x03\n\"UpdateColumnFieldEncryptionRequest\x12*\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12\x1b\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12l\n\x16\x65ncryption_key_storage\x18\x03 \x01(\tB6\xfa\x42\x33r1R\x12\x63ontrol_plane_onlyR\x1b\x63ontrol_plane_and_with_dataR\x14\x65ncryptionKeyStorage\x12*\n\x11\x65ncryption_key_id\x18\x04 \x01(\tR\x0f\x65ncryptionKeyId\x12W\n\x14\x65ncryption_algorithm\x18\x05 \x01(\tB$\xfa\x42!r\x1fR\x11\x61\x65s_deterministicR\naes_randomR\x13\x65ncryptionAlgorithm\x12\x32\n\x15\x65ncrypt_existing_data\x18\x06 \x01(\x08R\x13\x65ncryptExistingData\"%\n#UpdateColumnFieldEncryptionResponse\"d\n\x19GetInventoryObjectRequest\x12*\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12\x1b\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\"F\n\x1aGetInventoryObjectResponse\x12(\n\x06\x63olumn\x18\x01 \x01(\x0b\x32\x10.admin.v1.ColumnR\x06\x63olumn\"!\n\x1fGetInventoryHierarchicalRequest\"\x92\x07\n GetInventoryHierarchicalResponse\x12R\n\tinventory\x18\x01 \x03(\x0b\x32\x34.admin.v1.GetInventoryHierarchicalResponse.DatastoreR\tinventory\x1a\x90\x01\n\tDatastore\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1e\n\ntechnology\x18\x03 \x01(\tR\ntechnology\x12?\n\x03\x64\x62s\x18\x04 \x03(\x0b\x32-.admin.v1.GetInventoryHierarchicalResponse.DbR\x03\x64\x62s\x1a\xe6\x01\n\x02\x44\x62\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12K\n\x07schemas\x18\x04 \x03(\x0b\x32\x31.admin.v1.GetInventoryHierarchicalResponse.SchemaR\x07schemas\x12H\n\x06tables\x18\x05 \x03(\x0b\x32\x30.admin.v1.GetInventoryHierarchicalResponse.TableR\x06tables\x1a\x93\x01\n\x06Schema\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x17\n\x07\x64\x62_path\x18\x03 \x01(\tR\x06\x64\x62Path\x12H\n\x06tables\x18\x04 \x03(\x0b\x32\x30.admin.v1.GetInventoryHierarchicalResponse.TableR\x06tables\x1a\xb6\x01\n\x05Table\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x17\n\x07\x64\x62_path\x18\x03 \x01(\tR\x06\x64\x62Path\x12\x1f\n\x0bschema_path\x18\x04 \x01(\tR\nschemaPath\x12K\n\x07\x63olumns\x18\x05 \x03(\x0b\x32\x31.admin.v1.GetInventoryHierarchicalResponse.ColumnR\x07\x63olumns\x1aO\n\x06\x43olumn\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1d\n\ntable_path\x18\x03 \x01(\tR\ttablePath\"\xbf\x01\n\x13GetInventoryRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x04 \x01(\tR\x05order\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\x12%\n\x0e\x65xcluded_paths\x18\x06 \x03(\tR\rexcludedPaths\x12)\n\x10included_objects\x18\x07 \x03(\tR\x0fincludedObjects\"\x95\x01\n\x14GetInventoryResponse\x12\x37\n\tinventory\x18\x01 \x03(\x0b\x32\x19.admin.v1.InventoryObjectR\tinventory\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"s\n\x17GetInventoryFlatRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x14\n\x05\x61\x66ter\x18\x02 \x01(\tR\x05\x61\x66ter\x12\x16\n\x06\x62\x65\x66ore\x18\x03 \x01(\tR\x06\x62\x65\x66ore\x12\x14\n\x05order\x18\x04 \x01(\tR\x05order\"\xb3\x04\n\x06\x43olumn\x12\x1d\n\ncreated_at\x18\x01 \x01(\x03R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x02 \x01(\x03R\tupdatedAt\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x04 \x01(\tR\rdatastoreName\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\x12*\n\x11table_physical_id\x18\x06 \x01(\tR\x0ftablePhysicalId\x12\x34\n\x16table_attribute_number\x18\x07 \x01(\x04R\x14tableAttributeNumber\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x14\n\x05\x61lias\x18\t \x01(\tR\x05\x61lias\x12\x1d\n\ntable_path\x18\n \x01(\tR\ttablePath\x12\x1d\n\ndata_label\x18\x0b \x01(\tR\tdataLabel\x12\x1b\n\tdata_type\x18\x0c \x01(\tR\x08\x64\x61taType\x12\"\n\rdata_type_oid\x18\r \x01(\rR\x0b\x64\x61taTypeOid\x12@\n\x1d\x64\x61ta_label_locked_for_sidecar\x18\x0e \x01(\x08R\x19\x64\x61taLabelLockedForSidecar\x12\x12\n\x04tags\x18\x0f \x03(\tR\x04tags\x12\x1c\n\tencrypted\x18\x10 \x01(\x08R\tencrypted\x12\x0e\n\x02id\x18\x11 \x01(\tR\x02id\"h\n\x02\x44s\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1e\n\ntechnology\x18\x03 \x01(\tR\ntechnology\x12\x1e\n\x03\x64\x62s\x18\x04 \x03(\x0b\x32\x0c.admin.v1.DbR\x03\x64\x62s\"\xb4\x01\n\x02\x44\x62\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12*\n\x07schemas\x18\x04 \x03(\x0b\x32\x10.admin.v1.SchemaR\x07schemas\x12\'\n\x06tables\x18\x05 \x03(\x0b\x32\x0f.admin.v1.TableR\x06tables\x12\x0e\n\x02id\x18\x06 \x01(\tR\x02id\"\xa5\x01\n\x06Schema\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x17\n\x07\x64\x62_path\x18\x03 \x01(\tR\x06\x64\x62Path\x12\'\n\x06tables\x18\x04 \x03(\x0b\x32\x0f.admin.v1.TableR\x06tables\x12\x0e\n\x02id\x18\x05 \x01(\tR\x02id\x12!\n\x0c\x64\x61tastore_id\x18\x06 \x01(\tR\x0b\x64\x61tastoreId\"\xc8\x01\n\x05Table\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x17\n\x07\x64\x62_path\x18\x03 \x01(\tR\x06\x64\x62Path\x12\x1f\n\x0bschema_path\x18\x04 \x01(\tR\nschemaPath\x12*\n\x07\x63olumns\x18\x05 \x03(\x0b\x32\x10.admin.v1.ColumnR\x07\x63olumns\x12\x0e\n\x02id\x18\x06 \x01(\tR\x02id\x12!\n\x0c\x64\x61tastore_id\x18\x07 \x01(\tR\x0b\x64\x61tastoreId\"\xbe\x03\n\tSubColumn\x12\x1d\n\ncreated_at\x18\x01 \x01(\x03R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x02 \x01(\x03R\tupdatedAt\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x04 \x01(\tR\rdatastoreName\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x1d\n\ntable_path\x18\n \x01(\tR\ttablePath\x12\x1d\n\ndata_label\x18\x0b \x01(\tR\tdataLabel\x12\x1b\n\tdata_type\x18\x0c \x01(\tR\x08\x64\x61taType\x12\"\n\rdata_type_oid\x18\r \x01(\rR\x0b\x64\x61taTypeOid\x12@\n\x1d\x64\x61ta_label_locked_for_sidecar\x18\x0e \x01(\x08R\x19\x64\x61taLabelLockedForSidecar\x12\x12\n\x04tags\x18\x0f \x03(\tR\x04tags\x12\x1c\n\tencrypted\x18\x10 \x01(\x08R\tencrypted\x12\x0e\n\x02id\x18\x11 \x01(\tR\x02id\"\xa0\x02\n\x0fInventoryObject\x12,\n\tdatastore\x18\x01 \x01(\x0b\x32\x0c.admin.v1.DsH\x00R\tdatastore\x12\x1e\n\x02\x64\x62\x18\x02 \x01(\x0b\x32\x0c.admin.v1.DbH\x00R\x02\x64\x62\x12*\n\x06schema\x18\x03 \x01(\x0b\x32\x10.admin.v1.SchemaH\x00R\x06schema\x12\'\n\x05table\x18\x04 \x01(\x0b\x32\x0f.admin.v1.TableH\x00R\x05table\x12*\n\x06\x63olumn\x18\x05 \x01(\x0b\x32\x10.admin.v1.ColumnH\x00R\x06\x63olumn\x12\x34\n\nsub_column\x18\x06 \x01(\x0b\x32\x13.admin.v1.SubColumnH\x00R\tsubColumnB\x08\n\x06object\"\x99\x01\n\x18GetInventoryFlatResponse\x12\x37\n\tinventory\x18\x01 \x03(\x0b\x32\x19.admin.v1.InventoryObjectR\tinventory\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"\x86\x01\n\x1dUpdateColumnLockStatusRequest\x12*\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12\x1b\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x1c\n\tvalidated\x18\x03 \x01(\x08R\tvalidated\" \n\x1eUpdateColumnLockStatusResponse\"\x86\x01\n\x1cUpdateColumnDataLabelRequest\x12*\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12\x1b\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x1d\n\ndata_label\x18\x03 \x01(\tR\tdataLabel\"\x1f\n\x1dUpdateColumnDataLabelResponse\"\x9f\x07\n\x1c\x43reateInventoryObjectRequest\x12*\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12M\n\x0bobject_type\x18\x02 \x01(\tB,\xfa\x42)r\'R\x02\x64\x62R\x06schemaR\x05tableR\x06\x63olumnR\nsub-columnR\nobjectType\x12\x39\n\x02\x64\x62\x18\x03 \x01(\x0b\x32).admin.v1.CreateInventoryObjectRequest.DbR\x02\x64\x62\x12\x45\n\x06schema\x18\x04 \x01(\x0b\x32-.admin.v1.CreateInventoryObjectRequest.SchemaR\x06schema\x12\x42\n\x05table\x18\x05 \x01(\x0b\x32,.admin.v1.CreateInventoryObjectRequest.TableR\x05table\x12\x45\n\x06\x63olumn\x18\x06 \x01(\x0b\x32-.admin.v1.CreateInventoryObjectRequest.ColumnR\x06\x63olumn\x12O\n\nsub_column\x18\x07 \x01(\x0b\x32\x30.admin.v1.CreateInventoryObjectRequest.SubColumnR\tsubColumn\x1a>\n\x02\x44\x62\x12\x1b\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x1a\x42\n\x06Schema\x12\x1b\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x1a\x41\n\x05Table\x12\x1b\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x1ah\n\x06\x43olumn\x12\x1b\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12$\n\tdata_type\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08\x64\x61taType\x1au\n\tSubColumn\x12\x1b\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12.\n\x08sub_type\x18\x03 \x01(\tB\x13\xfa\x42\x10r\x0eR\x06hstoreR\x04jsonR\x07subType\"\x1f\n\x1d\x43reateInventoryObjectResponse\"g\n\x1c\x44\x65leteInventoryObjectRequest\x12*\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12\x1b\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\"\x1f\n\x1d\x44\x65leteInventoryObjectResponse\"w\n\x03Tag\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12\x43\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xfa\x42\x05\xb2\x01\x02\x08\x01R\tcreatedAt\"8\n\x19\x43reateInventoryTagRequest\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\"=\n\x1a\x43reateInventoryTagResponse\x12\x1f\n\x03tag\x18\x01 \x01(\x0b\x32\r.admin.v1.TagR\x03tag\"s\n\x17GetInventoryTagsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x14\n\x05\x61\x66ter\x18\x02 \x01(\tR\x05\x61\x66ter\x12\x16\n\x06\x62\x65\x66ore\x18\x03 \x01(\tR\x06\x62\x65\x66ore\x12\x14\n\x05order\x18\x04 \x01(\tR\x05order\"\x83\x01\n\x18GetInventoryTagsResponse\x12!\n\x04tags\x18\x01 \x03(\x0b\x32\r.admin.v1.TagR\x04tags\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"\x7f\n UpdateInventoryObjectTagsRequest\x12*\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12\x1b\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x12\n\x04tags\x18\x03 \x03(\tR\x04tags\"\xce\x04\n!UpdateInventoryObjectTagsResponse\x12S\n\x06object\x18\x01 \x01(\x0b\x32;.admin.v1.UpdateInventoryObjectTagsResponse.InventoryObjectR\x06object\x1a\xd3\x03\n\x0fInventoryObject\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x12\n\x04path\x18\x03 \x01(\tR\x04path\x12\x17\n\x07\x64\x62_path\x18\x04 \x01(\tR\x06\x64\x62Path\x12\x1d\n\ntable_path\x18\x05 \x01(\tR\ttablePath\x12\x1f\n\x0bschema_path\x18\x06 \x01(\tR\nschemaPath\x12\x34\n\x16table_attribute_number\x18\x07 \x01(\x04R\x14tableAttributeNumber\x12\x1b\n\tdata_type\x18\x08 \x01(\tR\x08\x64\x61taType\x12\x1d\n\ndata_label\x18\t \x01(\tR\tdataLabel\x12\x1d\n\nupdated_at\x18\n \x01(\x03R\tupdatedAt\x12\x1d\n\ncreated_at\x18\x0b \x01(\x03R\tcreatedAt\x12&\n\x0f\x64\x61ta_store_name\x18\x0c \x01(\tR\rdataStoreName\x12\x12\n\x04name\x18\r \x01(\tR\x04name\x12\x1c\n\tvalidated\x18\x0e \x01(\x08R\tvalidated\x12\x12\n\x04tags\x18\x0f \x03(\tR\x04tags\"4\n\x19\x44\x65leteInventoryTagRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"?\n\x1a\x44\x65leteInventoryTagResponse\x12!\n\x04tags\x18\x01 \x03(\x0b\x32\r.admin.v1.TagR\x04tags\"\xd8\x01\n\x1aGetInventoryMetricsRequest\x12 \n\x07user_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06userId\x12*\n\x0c\x64\x61tastore_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12\x1b\n\x04path\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12(\n\x0bobject_type\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nobjectType\x12%\n\ttimeframe\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttimeframe\"\xeb\x06\n\x1bGetInventoryMetricsResponse\x12\x46\n\x07metrics\x18\x01 \x03(\x0b\x32,.admin.v1.GetInventoryMetricsResponse.MetricR\x07metrics\x1a\x83\x06\n\x06Metric\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12\x1f\n\x0b\x63olumn_name\x18\x03 \x01(\tR\ncolumnName\x12\x1f\n\x0b\x63olumn_path\x18\x04 \x01(\tR\ncolumnPath\x12\x1d\n\ntable_name\x18\x05 \x01(\tR\ttableName\x12\x1d\n\ntable_path\x18\x06 \x01(\tR\ttablePath\x12\x1f\n\x0bschema_name\x18\x07 \x01(\tR\nschemaName\x12\x1f\n\x0bschema_path\x18\x08 \x01(\tR\nschemaPath\x12\x17\n\x07\x64\x62_name\x18\t \x01(\tR\x06\x64\x62Name\x12\x17\n\x07user_id\x18\n \x01(\tR\x06userId\x12\x17\n\x07\x64\x62_user\x18\x0b \x01(\tR\x06\x64\x62User\x12\x1e\n\x0b\x65nd_user_id\x18\x0c \x01(\tR\tendUserId\x12/\n\x14\x65nd_user_db_username\x18\r \x01(\tR\x11\x65ndUserDbUsername\x12\x19\n\x08\x61pp_type\x18\x0e \x01(\tR\x07\x61ppType\x12\x15\n\x06org_id\x18\x0f \x01(\tR\x05orgId\x12!\n\x0c\x64\x61tastore_id\x18\x10 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x11 \x01(\tR\rdatastoreName\x12\x0e\n\x02ts\x18\x12 \x01(\tR\x02ts\x12\x18\n\x07\x63ounter\x18\x13 \x01(\x05R\x07\x63ounter\x12#\n\rreturned_rows\x18\x14 \x01(\x05R\x0creturnedRows\x12\x1d\n\nip_address\x18\x15 \x01(\tR\tipAddress\x12\x1d\n\ndata_label\x18\x16 \x01(\tR\tdataLabel\x12\x1f\n\x0b\x64\x61ta_labels\x18\x17 \x03(\tR\ndataLabels\x12\x31\n\x14\x64\x61tastore_technology\x18\x18 \x01(\tR\x13\x64\x61tastoreTechnology\x12\x16\n\x06\x62ucket\x18\x19 \x01(\tR\x06\x62ucket\"\xcf\x01\n\x17\x43reateDataDomainRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x30\n\x06owners\x18\x03 \x03(\x0b\x32\x18.admin.v1.types.v1.OwnerR\x06owners\x12%\n\x0e\x65xcluded_paths\x18\x04 \x03(\tR\rexcludedPaths\x12%\n\x0eincluded_paths\x18\x05 \x03(\tR\rincludedPaths\"*\n\x18\x43reateDataDomainResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x17\n\x15GetDataDomainsRequest\"M\n\x16GetDataDomainsResponse\x12\x33\n\x07\x64omains\x18\x01 \x03(\x0b\x32\x19.admin.v1.types.v1.DomainR\x07\x64omains\"*\n\x18GetDataDomainByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"N\n\x19GetDataDomainByIdResponse\x12\x31\n\x06\x64omain\x18\x01 \x01(\x0b\x32\x19.admin.v1.types.v1.DomainR\x06\x64omain\"\xdf\x01\n\x17UpdateDataDomainRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x30\n\x06owners\x18\x04 \x03(\x0b\x32\x18.admin.v1.types.v1.OwnerR\x06owners\x12%\n\x0e\x65xcluded_paths\x18\x05 \x03(\tR\rexcludedPaths\x12%\n\x0eincluded_paths\x18\x06 \x03(\tR\rincludedPaths\"M\n\x18UpdateDataDomainResponse\x12\x31\n\x06\x64omain\x18\x01 \x01(\x0b\x32\x19.admin.v1.types.v1.DomainR\x06\x64omain\")\n\x17\x44\x65leteDataDomainRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1a\n\x18\x44\x65leteDataDomainResponse2\xf4\x0f\n\x10InventoryService\x12s\n\x18GetInventoryHierarchical\x12).admin.v1.GetInventoryHierarchicalRequest\x1a*.admin.v1.GetInventoryHierarchicalResponse\"\x00\x12O\n\x0cGetInventory\x12\x1d.admin.v1.GetInventoryRequest\x1a\x1e.admin.v1.GetInventoryResponse\"\x00\x12[\n\x10GetInventoryFlat\x12!.admin.v1.GetInventoryFlatRequest\x1a\".admin.v1.GetInventoryFlatResponse\"\x00\x12\x64\n\x13GetInventoryFlatOld\x12$.admin.v1.GetInventoryFlatOldRequest\x1a%.admin.v1.GetInventoryFlatOldResponse\"\x00\x12\x61\n\x12GetInventoryObject\x12#.admin.v1.GetInventoryObjectRequest\x1a$.admin.v1.GetInventoryObjectResponse\"\x00\x12m\n\x16UpdateColumnLockStatus\x12\'.admin.v1.UpdateColumnLockStatusRequest\x1a(.admin.v1.UpdateColumnLockStatusResponse\"\x00\x12j\n\x15UpdateColumnDataLabel\x12&.admin.v1.UpdateColumnDataLabelRequest\x1a\'.admin.v1.UpdateColumnDataLabelResponse\"\x00\x12|\n\x1bUpdateColumnFieldEncryption\x12,.admin.v1.UpdateColumnFieldEncryptionRequest\x1a-.admin.v1.UpdateColumnFieldEncryptionResponse\"\x00\x12v\n\x19UpdateInventoryObjectTags\x12*.admin.v1.UpdateInventoryObjectTagsRequest\x1a+.admin.v1.UpdateInventoryObjectTagsResponse\"\x00\x12j\n\x15\x43reateInventoryObject\x12&.admin.v1.CreateInventoryObjectRequest\x1a\'.admin.v1.CreateInventoryObjectResponse\"\x00\x12j\n\x15\x44\x65leteInventoryObject\x12&.admin.v1.DeleteInventoryObjectRequest\x1a\'.admin.v1.DeleteInventoryObjectResponse\"\x00\x12\x61\n\x12\x43reateInventoryTag\x12#.admin.v1.CreateInventoryTagRequest\x1a$.admin.v1.CreateInventoryTagResponse\"\x00\x12[\n\x10GetInventoryTags\x12!.admin.v1.GetInventoryTagsRequest\x1a\".admin.v1.GetInventoryTagsResponse\"\x00\x12\x61\n\x12\x44\x65leteInventoryTag\x12#.admin.v1.DeleteInventoryTagRequest\x1a$.admin.v1.DeleteInventoryTagResponse\"\x00\x12\x64\n\x13GetInventoryMetrics\x12$.admin.v1.GetInventoryMetricsRequest\x1a%.admin.v1.GetInventoryMetricsResponse\"\x00\x12Y\n\x10\x43reateDataDomain\x12!.admin.v1.CreateDataDomainRequest\x1a\".admin.v1.CreateDataDomainResponse\x12S\n\x0eGetDataDomains\x12\x1f.admin.v1.GetDataDomainsRequest\x1a .admin.v1.GetDataDomainsResponse\x12\\\n\x11GetDataDomainById\x12\".admin.v1.GetDataDomainByIdRequest\x1a#.admin.v1.GetDataDomainByIdResponse\x12Y\n\x10UpdateDataDomain\x12!.admin.v1.UpdateDataDomainRequest\x1a\".admin.v1.UpdateDataDomainResponse\x12Y\n\x10\x44\x65leteDataDomain\x12!.admin.v1.DeleteDataDomainRequest\x1a\".admin.v1.DeleteDataDomainResponseB\xa9\x01\n\x0c\x63om.admin.v1B\x0eInventoryProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.inventory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\016InventoryProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['path']._options = None
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['encryption_key_storage']._options = None
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['encryption_key_storage']._serialized_options = b'\372B3r1R\022control_plane_onlyR\033control_plane_and_with_data'
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['encryption_algorithm']._options = None
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['encryption_algorithm']._serialized_options = b'\372B!r\037R\021aes_deterministicR\naes_random'
  _globals['_GETINVENTORYOBJECTREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_GETINVENTORYOBJECTREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETINVENTORYOBJECTREQUEST'].fields_by_name['path']._options = None
  _globals['_GETINVENTORYOBJECTREQUEST'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATECOLUMNLOCKSTATUSREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_UPDATECOLUMNLOCKSTATUSREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATECOLUMNLOCKSTATUSREQUEST'].fields_by_name['path']._options = None
  _globals['_UPDATECOLUMNLOCKSTATUSREQUEST'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATECOLUMNDATALABELREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_UPDATECOLUMNDATALABELREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATECOLUMNDATALABELREQUEST'].fields_by_name['path']._options = None
  _globals['_UPDATECOLUMNDATALABELREQUEST'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_DB'].fields_by_name['path']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_DB'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_DB'].fields_by_name['name']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_DB'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_SCHEMA'].fields_by_name['path']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_SCHEMA'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_SCHEMA'].fields_by_name['name']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_SCHEMA'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_TABLE'].fields_by_name['path']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_TABLE'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_TABLE'].fields_by_name['name']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_TABLE'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN'].fields_by_name['path']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN'].fields_by_name['name']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN'].fields_by_name['data_type']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN'].fields_by_name['data_type']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN'].fields_by_name['path']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN'].fields_by_name['name']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN'].fields_by_name['sub_type']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN'].fields_by_name['sub_type']._serialized_options = b'\372B\020r\016R\006hstoreR\004json'
  _globals['_CREATEINVENTORYOBJECTREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST'].fields_by_name['object_type']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST'].fields_by_name['object_type']._serialized_options = b'\372B)r\'R\002dbR\006schemaR\005tableR\006columnR\nsub-column'
  _globals['_DELETEINVENTORYOBJECTREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_DELETEINVENTORYOBJECTREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DELETEINVENTORYOBJECTREQUEST'].fields_by_name['path']._options = None
  _globals['_DELETEINVENTORYOBJECTREQUEST'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_TAG'].fields_by_name['name']._options = None
  _globals['_TAG'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_TAG'].fields_by_name['created_at']._options = None
  _globals['_TAG'].fields_by_name['created_at']._serialized_options = b'\372B\005\262\001\002\010\001'
  _globals['_CREATEINVENTORYTAGREQUEST'].fields_by_name['name']._options = None
  _globals['_CREATEINVENTORYTAGREQUEST'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATEINVENTORYOBJECTTAGSREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_UPDATEINVENTORYOBJECTTAGSREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATEINVENTORYOBJECTTAGSREQUEST'].fields_by_name['path']._options = None
  _globals['_UPDATEINVENTORYOBJECTTAGSREQUEST'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DELETEINVENTORYTAGREQUEST'].fields_by_name['id']._options = None
  _globals['_DELETEINVENTORYTAGREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['user_id']._options = None
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['path']._options = None
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['object_type']._options = None
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['object_type']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['timeframe']._options = None
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['timeframe']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETINVENTORYFLATOLDREQUEST']._serialized_start=170
  _globals['_GETINVENTORYFLATOLDREQUEST']._serialized_end=198
  _globals['_COLUMNOLD']._serialized_start=201
  _globals['_COLUMNOLD']._serialized_end=751
  _globals['_GETINVENTORYFLATOLDRESPONSE']._serialized_start=753
  _globals['_GETINVENTORYFLATOLDRESPONSE']._serialized_end=833
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST']._serialized_start=836
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST']._serialized_end=1240
  _globals['_UPDATECOLUMNFIELDENCRYPTIONRESPONSE']._serialized_start=1242
  _globals['_UPDATECOLUMNFIELDENCRYPTIONRESPONSE']._serialized_end=1279
  _globals['_GETINVENTORYOBJECTREQUEST']._serialized_start=1281
  _globals['_GETINVENTORYOBJECTREQUEST']._serialized_end=1381
  _globals['_GETINVENTORYOBJECTRESPONSE']._serialized_start=1383
  _globals['_GETINVENTORYOBJECTRESPONSE']._serialized_end=1453
  _globals['_GETINVENTORYHIERARCHICALREQUEST']._serialized_start=1455
  _globals['_GETINVENTORYHIERARCHICALREQUEST']._serialized_end=1488
  _globals['_GETINVENTORYHIERARCHICALRESPONSE']._serialized_start=1491
  _globals['_GETINVENTORYHIERARCHICALRESPONSE']._serialized_end=2405
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_DATASTORE']._serialized_start=1612
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_DATASTORE']._serialized_end=1756
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_DB']._serialized_start=1759
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_DB']._serialized_end=1989
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_SCHEMA']._serialized_start=1992
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_SCHEMA']._serialized_end=2139
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_TABLE']._serialized_start=2142
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_TABLE']._serialized_end=2324
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_COLUMN']._serialized_start=2326
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_COLUMN']._serialized_end=2405
  _globals['_GETINVENTORYREQUEST']._serialized_start=2408
  _globals['_GETINVENTORYREQUEST']._serialized_end=2599
  _globals['_GETINVENTORYRESPONSE']._serialized_start=2602
  _globals['_GETINVENTORYRESPONSE']._serialized_end=2751
  _globals['_GETINVENTORYFLATREQUEST']._serialized_start=2753
  _globals['_GETINVENTORYFLATREQUEST']._serialized_end=2868
  _globals['_COLUMN']._serialized_start=2871
  _globals['_COLUMN']._serialized_end=3434
  _globals['_DS']._serialized_start=3436
  _globals['_DS']._serialized_end=3540
  _globals['_DB']._serialized_start=3543
  _globals['_DB']._serialized_end=3723
  _globals['_SCHEMA']._serialized_start=3726
  _globals['_SCHEMA']._serialized_end=3891
  _globals['_TABLE']._serialized_start=3894
  _globals['_TABLE']._serialized_end=4094
  _globals['_SUBCOLUMN']._serialized_start=4097
  _globals['_SUBCOLUMN']._serialized_end=4543
  _globals['_INVENTORYOBJECT']._serialized_start=4546
  _globals['_INVENTORYOBJECT']._serialized_end=4834
  _globals['_GETINVENTORYFLATRESPONSE']._serialized_start=4837
  _globals['_GETINVENTORYFLATRESPONSE']._serialized_end=4990
  _globals['_UPDATECOLUMNLOCKSTATUSREQUEST']._serialized_start=4993
  _globals['_UPDATECOLUMNLOCKSTATUSREQUEST']._serialized_end=5127
  _globals['_UPDATECOLUMNLOCKSTATUSRESPONSE']._serialized_start=5129
  _globals['_UPDATECOLUMNLOCKSTATUSRESPONSE']._serialized_end=5161
  _globals['_UPDATECOLUMNDATALABELREQUEST']._serialized_start=5164
  _globals['_UPDATECOLUMNDATALABELREQUEST']._serialized_end=5298
  _globals['_UPDATECOLUMNDATALABELRESPONSE']._serialized_start=5300
  _globals['_UPDATECOLUMNDATALABELRESPONSE']._serialized_end=5331
  _globals['_CREATEINVENTORYOBJECTREQUEST']._serialized_start=5334
  _globals['_CREATEINVENTORYOBJECTREQUEST']._serialized_end=6261
  _globals['_CREATEINVENTORYOBJECTREQUEST_DB']._serialized_start=5839
  _globals['_CREATEINVENTORYOBJECTREQUEST_DB']._serialized_end=5901
  _globals['_CREATEINVENTORYOBJECTREQUEST_SCHEMA']._serialized_start=5903
  _globals['_CREATEINVENTORYOBJECTREQUEST_SCHEMA']._serialized_end=5969
  _globals['_CREATEINVENTORYOBJECTREQUEST_TABLE']._serialized_start=5971
  _globals['_CREATEINVENTORYOBJECTREQUEST_TABLE']._serialized_end=6036
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN']._serialized_start=6038
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN']._serialized_end=6142
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN']._serialized_start=6144
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN']._serialized_end=6261
  _globals['_CREATEINVENTORYOBJECTRESPONSE']._serialized_start=6263
  _globals['_CREATEINVENTORYOBJECTRESPONSE']._serialized_end=6294
  _globals['_DELETEINVENTORYOBJECTREQUEST']._serialized_start=6296
  _globals['_DELETEINVENTORYOBJECTREQUEST']._serialized_end=6399
  _globals['_DELETEINVENTORYOBJECTRESPONSE']._serialized_start=6401
  _globals['_DELETEINVENTORYOBJECTRESPONSE']._serialized_end=6432
  _globals['_TAG']._serialized_start=6434
  _globals['_TAG']._serialized_end=6553
  _globals['_CREATEINVENTORYTAGREQUEST']._serialized_start=6555
  _globals['_CREATEINVENTORYTAGREQUEST']._serialized_end=6611
  _globals['_CREATEINVENTORYTAGRESPONSE']._serialized_start=6613
  _globals['_CREATEINVENTORYTAGRESPONSE']._serialized_end=6674
  _globals['_GETINVENTORYTAGSREQUEST']._serialized_start=6676
  _globals['_GETINVENTORYTAGSREQUEST']._serialized_end=6791
  _globals['_GETINVENTORYTAGSRESPONSE']._serialized_start=6794
  _globals['_GETINVENTORYTAGSRESPONSE']._serialized_end=6925
  _globals['_UPDATEINVENTORYOBJECTTAGSREQUEST']._serialized_start=6927
  _globals['_UPDATEINVENTORYOBJECTTAGSREQUEST']._serialized_end=7054
  _globals['_UPDATEINVENTORYOBJECTTAGSRESPONSE']._serialized_start=7057
  _globals['_UPDATEINVENTORYOBJECTTAGSRESPONSE']._serialized_end=7647
  _globals['_UPDATEINVENTORYOBJECTTAGSRESPONSE_INVENTORYOBJECT']._serialized_start=7180
  _globals['_UPDATEINVENTORYOBJECTTAGSRESPONSE_INVENTORYOBJECT']._serialized_end=7647
  _globals['_DELETEINVENTORYTAGREQUEST']._serialized_start=7649
  _globals['_DELETEINVENTORYTAGREQUEST']._serialized_end=7701
  _globals['_DELETEINVENTORYTAGRESPONSE']._serialized_start=7703
  _globals['_DELETEINVENTORYTAGRESPONSE']._serialized_end=7766
  _globals['_GETINVENTORYMETRICSREQUEST']._serialized_start=7769
  _globals['_GETINVENTORYMETRICSREQUEST']._serialized_end=7985
  _globals['_GETINVENTORYMETRICSRESPONSE']._serialized_start=7988
  _globals['_GETINVENTORYMETRICSRESPONSE']._serialized_end=8863
  _globals['_GETINVENTORYMETRICSRESPONSE_METRIC']._serialized_start=8092
  _globals['_GETINVENTORYMETRICSRESPONSE_METRIC']._serialized_end=8863
  _globals['_CREATEDATADOMAINREQUEST']._serialized_start=8866
  _globals['_CREATEDATADOMAINREQUEST']._serialized_end=9073
  _globals['_CREATEDATADOMAINRESPONSE']._serialized_start=9075
  _globals['_CREATEDATADOMAINRESPONSE']._serialized_end=9117
  _globals['_GETDATADOMAINSREQUEST']._serialized_start=9119
  _globals['_GETDATADOMAINSREQUEST']._serialized_end=9142
  _globals['_GETDATADOMAINSRESPONSE']._serialized_start=9144
  _globals['_GETDATADOMAINSRESPONSE']._serialized_end=9221
  _globals['_GETDATADOMAINBYIDREQUEST']._serialized_start=9223
  _globals['_GETDATADOMAINBYIDREQUEST']._serialized_end=9265
  _globals['_GETDATADOMAINBYIDRESPONSE']._serialized_start=9267
  _globals['_GETDATADOMAINBYIDRESPONSE']._serialized_end=9345
  _globals['_UPDATEDATADOMAINREQUEST']._serialized_start=9348
  _globals['_UPDATEDATADOMAINREQUEST']._serialized_end=9571
  _globals['_UPDATEDATADOMAINRESPONSE']._serialized_start=9573
  _globals['_UPDATEDATADOMAINRESPONSE']._serialized_end=9650
  _globals['_DELETEDATADOMAINREQUEST']._serialized_start=9652
  _globals['_DELETEDATADOMAINREQUEST']._serialized_end=9693
  _globals['_DELETEDATADOMAINRESPONSE']._serialized_start=9695
  _globals['_DELETEDATADOMAINRESPONSE']._serialized_end=9721
  _globals['_INVENTORYSERVICE']._serialized_start=9724
  _globals['_INVENTORYSERVICE']._serialized_end=11760
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/integration_datahub.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import datahub_pb2 as admin_dot_v1_dot_types_dot_v1_dot_datahub__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"admin/v1/integration_datahub.proto\x12\x08\x61\x64min.v1\x1a\x1f\x61\x64min/v1/types/v1/datahub.proto\x1a\x1avalidate/v1/validate.proto\"\xa7\x02\n\x1f\x43reateDatahubIntegrationRequest\x12\x61\n\x0esync_direction\x18\x01 \x01(\tB:\xfa\x42\x37r5R\rbidirectionalR\x11\x66ormal_to_datahubR\x11\x64\x61tahub_to_formalR\rsyncDirection\x12G\n generalized_metadata_service_url\x18\x02 \x01(\tR\x1dgeneralizedMetadataServiceUrl\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x17\n\x07\x61pi_key\x18\x04 \x01(\tR\x06\x61piKey\x12\'\n\x0fsynced_entities\x18\x05 \x03(\tR\x0esyncedEntities\"2\n CreateDatahubIntegrationResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"7\n\x1cGetDatahubIntegrationRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"]\n\x1dGetDatahubIntegrationResponse\x12<\n\x0bintegration\x18\x01 \x01(\x0b\x32\x1a.admin.v1.types.v1.DatahubR\x0bintegration\"\xba\x02\n\x1fUpdateDatahubIntegrationRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x64\n\x0esync_direction\x18\x02 \x01(\tB=\xfa\x42:r8R\rbidirectionalR\x11\x66ormal_to_datahubR\x11\x64\x61tahub_to_formal\xd0\x01\x01R\rsyncDirection\x12G\n generalized_metadata_service_url\x18\x03 \x01(\tR\x1dgeneralizedMetadataServiceUrl\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x17\n\x07\x61pi_key\x18\x05 \x01(\tR\x06\x61piKey\x12\'\n\x0fsynced_entities\x18\x06 \x03(\tR\x0esyncedEntities\"`\n UpdateDatahubIntegrationResponse\x12<\n\x0bintegration\x18\x01 \x01(\x0b\x32\x1a.admin.v1.types.v1.DatahubR\x0bintegration\",\n\x1aRefreshWebhookTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"3\n\x1bRefreshWebhookTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\"1\n\x1f\x44\x65leteDatahubIntegrationRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\"\n DeleteDatahubIntegrationResponse2\xc1\x04\n\x0e\x44\x61tahubService\x12s\n\x18\x43reateDatahubIntegration\x12).admin.v1.CreateDatahubIntegrationRequest\x1a*.admin.v1.CreateDatahubIntegrationResponse\"\x00\x12j\n\x15GetDatahubIntegration\x12&.admin.v1.GetDatahubIntegrationRequest\x1a\'.admin.v1.GetDatahubIntegrationResponse\"\x00\x12s\n\x18UpdateDatahubIntegration\x12).admin.v1.UpdateDatahubIntegrationRequest\x1a*.admin.v1.UpdateDatahubIntegrationResponse\"\x00\x12\x64\n\x13RefreshWebhookToken\x12$.admin.v1.RefreshWebhookTokenRequest\x1a%.admin.v1.RefreshWebhookTokenResponse\"\x00\x12s\n\x18\x44\x65leteDatahubIntegration\x12).admin.v1.DeleteDatahubIntegrationRequest\x1a*.admin.v1.DeleteDatahubIntegrationResponse\"\x00\x42\xb2\x01\n\x0c\x63om.admin.v1B\x17IntegrationDatahubProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_datahub_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\027IntegrationDatahubProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATEDATAHUBINTEGRATIONREQUEST'].fields_by_name['sync_direction']._options = None
  _globals['_CREATEDATAHUBINTEGRATIONREQUEST'].fields_by_name['sync_direction']._serialized_options = b'\372B7r5R\rbidirectionalR\021formal_to_datahubR\021datahub_to_formal'
  _globals['_GETDATAHUBINTEGRATIONREQUEST'].fields_by_name['id']._options = None
  _globals['_GETDATAHUBINTEGRATIONREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATEDATAHUBINTEGRATIONREQUEST'].fields_by_name['sync_direction']._options = None
  _globals['_UPDATEDATAHUBINTEGRATIONREQUEST'].fields_by_name['sync_direction']._serialized_options = b'\372B:r8R\rbidirectionalR\021formal_to_datahubR\021datahub_to_formal\320\001\001'
  _globals['_CREATEDATAHUBINTEGRATIONREQUEST']._serialized_start=110
  _globals['_CREATEDATAHUBINTEGRATIONREQUEST']._serialized_end=405
  _globals['_CREATEDATAHUBINTEGRATIONRESPONSE']._serialized_start=407
  _globals['_CREATEDATAHUBINTEGRATIONRESPONSE']._serialized_end=457
  _globals['_GETDATAHUBINTEGRATIONREQUEST']._serialized_start=459
  _globals['_GETDATAHUBINTEGRATIONREQUEST']._serialized_end=514
  _globals['_GETDATAHUBINTEGRATIONRESPONSE']._serialized_start=516
  _globals['_GETDATAHUBINTEGRATIONRESPONSE']._serialized_end=609
  _globals['_UPDATEDATAHUBINTEGRATIONREQUEST']._serialized_start=612
  _globals['_UPDATEDATAHUBINTEGRATIONREQUEST']._serialized_end=926
  _globals['_UPDATEDATAHUBINTEGRATIONRESPONSE']._serialized_start=928
  _globals['_UPDATEDATAHUBINTEGRATIONRESPONSE']._serialized_end=1024
  _globals['_REFRESHWEBHOOKTOKENREQUEST']._serialized_start=1026
  _globals['_REFRESHWEBHOOKTOKENREQUEST']._serialized_end=1070
  _globals['_REFRESHWEBHOOKTOKENRESPONSE']._serialized_start=1072
  _globals['_REFRESHWEBHOOKTOKENRESPONSE']._serialized_end=1123
  _globals['_DELETEDATAHUBINTEGRATIONREQUEST']._serialized_start=1125
  _globals['_DELETEDATAHUBINTEGRATIONREQUEST']._serialized_end=1174
  _globals['_DELETEDATAHUBINTEGRATIONRESPONSE']._serialized_start=1176
  _globals['_DELETEDATAHUBINTEGRATIONRESPONSE']._serialized_end=1210
  _globals['_DATAHUBSERVICE']._serialized_start=1213
  _globals['_DATAHUBSERVICE']._serialized_end=1790
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Datastore(_message.Message):
    __slots__ = ["id", "created_at", "datastore_id", "name", "original_hostname", "port", "technology", "health_check_db_name", "default_access_behavior", "db_discovery_job_wait_time", "db_discovery_native_role_id", "username", "password", "environment"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ORIGINAL_HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    HEALTH_CHECK_DB_NAME_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_ACCESS_BEHAVIOR_FIELD_NUMBER: _ClassVar[int]
    DB_DISCOVERY_JOB_WAIT_TIME_FIELD_NUMBER: _ClassVar[int]
    DB_DISCOVERY_NATIVE_ROLE_ID_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    id: str
    created_at: int
    datastore_id: str
    name: str
    original_hostname: str
    port: int
    technology: str
    health_check_db_name: str
    default_access_behavior: str
    db_discovery_job_wait_time: str
    db_discovery_native_role_id: str
    username: str
    password: str
    environment: str
    def __init__(self, id: _Optional[str] = ..., created_at: _Optional[int] = ..., datastore_id: _Optional[str] = ..., name: _Optional[str] = ..., original_hostname: _Optional[str] = ..., port: _Optional[int] = ..., technology: _Optional[str] = ..., health_check_db_name: _Optional[str] = ..., default_access_behavior: _Optional[str] = ..., db_discovery_job_wait_time: _Optional[str] = ..., db_discovery_native_role_id: _Optional[str] = ..., username: _Optional[str] = ..., password: _Optional[str] = ..., environment: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ListMetadata(_message.Message):
    __slots__ = ["after", "before", "count", "next_cursor"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    NEXT_CURSOR_FIELD_NUMBER: _ClassVar[int]
    after: str
    before: str
    count: int
    next_cursor: str
    def __init__(self, after: _Optional[str] = ..., before: _Optional[str] = ..., count: _Optional[int] = ..., next_cursor: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/permissions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61\x64min/v1/permissions.proto\x12\x08\x61\x64min.v1\":\n\x1eGetPermissionsByServiceRequest\x12\x18\n\x07service\x18\x01 \x01(\tR\x07service\"\xbf\x01\n\x1fGetPermissionsByServiceResponse\x12\\\n\x0bpermissions\x18\x01 \x03(\x0b\x32:.admin.v1.GetPermissionsByServiceResponse.PermissionsEntryR\x0bpermissions\x1a>\n\x10PermissionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x08R\x05value:\x02\x38\x01\"\x17\n\x15GetPermissionsRequest\"\xad\x01\n\x16GetPermissionsResponse\x12S\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x31.admin.v1.GetPermissionsResponse.PermissionsEntryR\x0bpermissions\x1a>\n\x10PermissionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x08R\x05value:\x02\x38\x01\x32\xdc\x01\n\x11PermissionService\x12U\n\x0eGetPermissions\x12\x1f.admin.v1.GetPermissionsRequest\x1a .admin.v1.GetPermissionsResponse\"\x00\x12p\n\x17GetPermissionsByService\x12(.admin.v1.GetPermissionsByServiceRequest\x1a).admin.v1.GetPermissionsByServiceResponse\"\x00\x42\xab\x01\n\x0c\x63om.admin.v1B\x10PermissionsProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.permissions_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\020PermissionsProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETPERMISSIONSBYSERVICERESPONSE_PERMISSIONSENTRY']._options = None
  _globals['_GETPERMISSIONSBYSERVICERESPONSE_PERMISSIONSENTRY']._serialized_options = b'8\001'
  _globals['_GETPERMISSIONSRESPONSE_PERMISSIONSENTRY']._options = None
  _globals['_GETPERMISSIONSRESPONSE_PERMISSIONSENTRY']._serialized_options = b'8\001'
  _globals['_GETPERMISSIONSBYSERVICEREQUEST']._serialized_start=40
  _globals['_GETPERMISSIONSBYSERVICEREQUEST']._serialized_end=98
  _globals['_GETPERMISSIONSBYSERVICERESPONSE']._serialized_start=101
  _globals['_GETPERMISSIONSBYSERVICERESPONSE']._serialized_end=292
  _globals['_GETPERMISSIONSBYSERVICERESPONSE_PERMISSIONSENTRY']._serialized_start=230
  _globals['_GETPERMISSIONSBYSERVICERESPONSE_PERMISSIONSENTRY']._serialized_end=292
  _globals['_GETPERMISSIONSREQUEST']._serialized_start=294
  _globals['_GETPERMISSIONSREQUEST']._serialized_end=317
  _globals['_GETPERMISSIONSRESPONSE']._serialized_start=320
  _globals['_GETPERMISSIONSRESPONSE']._serialized_end=493
  _globals['_GETPERMISSIONSRESPONSE_PERMISSIONSENTRY']._serialized_start=230
  _globals['_GETPERMISSIONSRESPONSE_PERMISSIONSENTRY']._serialized_end=292
  _globals['_PERMISSIONSERVICE']._serialized_start=496
  _globals['_PERMISSIONSERVICE']._serialized_end=716
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import satellite_pb2 as admin_dot_v1_dot_satellite__pb2


class SatelliteServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateSatellite = channel.unary_unary(
                '/admin.v1.SatelliteService/CreateSatellite',
                request_serializer=admin_dot_v1_dot_satellite__pb2.CreateSatelliteRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_satellite__pb2.CreateSatelliteResponse.FromString,
                )
        self.GetSatelliteById = channel.unary_unary(
                '/admin.v1.SatelliteService/GetSatelliteById',
                request_serializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteByIdResponse.FromString,
                )
        self.GetSatellites = channel.unary_unary(
                '/admin.v1.SatelliteService/GetSatellites',
                request_serializer=admin_dot_v1_dot_satellite__pb2.GetSatellitesRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_satellite__pb2.GetSatellitesResponse.FromString,
                )
        self.GetSatelliteApiKey = channel.unary_unary(
                '/admin.v1.SatelliteService/GetSatelliteApiKey',
                request_serializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteApiKeyRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteApiKeyResponse.FromString,
                )
        self.DeleteSatellite = channel.unary_unary(
                '/admin.v1.SatelliteService/DeleteSatellite',
                request_serializer=admin_dot_v1_dot_satellite__pb2.DeleteSatelliteRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_satellite__pb2.DeleteSatelliteResponse.FromString,
                )


class SatelliteServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateSatellite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSatelliteById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSatellites(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSatelliteApiKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSatellite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SatelliteServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateSatellite': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSatellite,
                    request_deserializer=admin_dot_v1_dot_satellite__pb2.CreateSatelliteRequest.FromString,
                    response_serializer=admin_dot_v1_dot_satellite__pb2.CreateSatelliteResponse.SerializeToString,
            ),
            'GetSatelliteById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSatelliteById,
                    request_deserializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteByIdResponse.SerializeToString,
            ),
            'GetSatellites': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSatellites,
                    request_deserializer=admin_dot_v1_dot_satellite__pb2.GetSatellitesRequest.FromString,
                    response_serializer=admin_dot_v1_dot_satellite__pb2.GetSatellitesResponse.SerializeToString,
            ),
            'GetSatelliteApiKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSatelliteApiKey,
                    request_deserializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteApiKeyRequest.FromString,
                    response_serializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteApiKeyResponse.SerializeToString,
            ),
            'DeleteSatellite': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSatellite,
                    request_deserializer=admin_dot_v1_dot_satellite__pb2.DeleteSatelliteRequest.FromString,
                    response_serializer=admin_dot_v1_dot_satellite__pb2.DeleteSatelliteResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.SatelliteService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SatelliteService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateSatellite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SatelliteService/CreateSatellite',
            admin_dot_v1_dot_satellite__pb2.CreateSatelliteRequest.SerializeToString,
            admin_dot_v1_dot_satellite__pb2.CreateSatelliteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSatelliteById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SatelliteService/GetSatelliteById',
            admin_dot_v1_dot_satellite__pb2.GetSatelliteByIdRequest.SerializeToString,
            admin_dot_v1_dot_satellite__pb2.GetSatelliteByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSatellites(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SatelliteService/GetSatellites',
            admin_dot_v1_dot_satellite__pb2.GetSatellitesRequest.SerializeToString,
            admin_dot_v1_dot_satellite__pb2.GetSatellitesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSatelliteApiKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SatelliteService/GetSatelliteApiKey',
            admin_dot_v1_dot_satellite__pb2.GetSatelliteApiKeyRequest.SerializeToString,
            admin_dot_v1_dot_satellite__pb2.GetSatelliteApiKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSatellite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SatelliteService/DeleteSatellite',
            admin_dot_v1_dot_satellite__pb2.DeleteSatelliteRequest.SerializeToString,
            admin_dot_v1_dot_satellite__pb2.DeleteSatelliteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: validate/v1/validate.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avalidate/v1/validate.proto\x12\x0bvalidate.v1\x1a google/protobuf/descriptor.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8a\t\n\nFieldRules\x12\x33\n\x07message\x18\x11 \x01(\x0b\x32\x19.validate.v1.MessageRulesR\x07message\x12/\n\x05\x66loat\x18\x01 \x01(\x0b\x32\x17.validate.v1.FloatRulesH\x00R\x05\x66loat\x12\x32\n\x06\x64ouble\x18\x02 \x01(\x0b\x32\x18.validate.v1.DoubleRulesH\x00R\x06\x64ouble\x12/\n\x05int32\x18\x03 \x01(\x0b\x32\x17.validate.v1.Int32RulesH\x00R\x05int32\x12/\n\x05int64\x18\x04 \x01(\x0b\x32\x17.validate.v1.Int64RulesH\x00R\x05int64\x12\x32\n\x06uint32\x18\x05 \x01(\x0b\x32\x18.validate.v1.UInt32RulesH\x00R\x06uint32\x12\x32\n\x06uint64\x18\x06 \x01(\x0b\x32\x18.validate.v1.UInt64RulesH\x00R\x06uint64\x12\x32\n\x06sint32\x18\x07 \x01(\x0b\x32\x18.validate.v1.SInt32RulesH\x00R\x06sint32\x12\x32\n\x06sint64\x18\x08 \x01(\x0b\x32\x18.validate.v1.SInt64RulesH\x00R\x06sint64\x12\x35\n\x07\x66ixed32\x18\t \x01(\x0b\x32\x19.validate.v1.Fixed32RulesH\x00R\x07\x66ixed32\x12\x35\n\x07\x66ixed64\x18\n \x01(\x0b\x32\x19.validate.v1.Fixed64RulesH\x00R\x07\x66ixed64\x12\x38\n\x08sfixed32\x18\x0b \x01(\x0b\x32\x1a.validate.v1.SFixed32RulesH\x00R\x08sfixed32\x12\x38\n\x08sfixed64\x18\x0c \x01(\x0b\x32\x1a.validate.v1.SFixed64RulesH\x00R\x08sfixed64\x12,\n\x04\x62ool\x18\r \x01(\x0b\x32\x16.validate.v1.BoolRulesH\x00R\x04\x62ool\x12\x32\n\x06string\x18\x0e \x01(\x0b\x32\x18.validate.v1.StringRulesH\x00R\x06string\x12/\n\x05\x62ytes\x18\x0f \x01(\x0b\x32\x17.validate.v1.BytesRulesH\x00R\x05\x62ytes\x12,\n\x04\x65num\x18\x10 \x01(\x0b\x32\x16.validate.v1.EnumRulesH\x00R\x04\x65num\x12\x38\n\x08repeated\x18\x12 \x01(\x0b\x32\x1a.validate.v1.RepeatedRulesH\x00R\x08repeated\x12)\n\x03map\x18\x13 \x01(\x0b\x32\x15.validate.v1.MapRulesH\x00R\x03map\x12)\n\x03\x61ny\x18\x14 \x01(\x0b\x32\x15.validate.v1.AnyRulesH\x00R\x03\x61ny\x12\x38\n\x08\x64uration\x18\x15 \x01(\x0b\x32\x1a.validate.v1.DurationRulesH\x00R\x08\x64uration\x12;\n\ttimestamp\x18\x16 \x01(\x0b\x32\x1b.validate.v1.TimestampRulesH\x00R\ttimestampB\x06\n\x04type\"\xb0\x01\n\nFloatRules\x12\x14\n\x05\x63onst\x18\x01 \x01(\x02R\x05\x63onst\x12\x0e\n\x02lt\x18\x02 \x01(\x02R\x02lt\x12\x10\n\x03lte\x18\x03 \x01(\x02R\x03lte\x12\x0e\n\x02gt\x18\x04 \x01(\x02R\x02gt\x12\x10\n\x03gte\x18\x05 \x01(\x02R\x03gte\x12\x0e\n\x02in\x18\x06 \x03(\x02R\x02in\x12\x15\n\x06not_in\x18\x07 \x03(\x02R\x05notIn\x12!\n\x0cignore_empty\x18\x08 \x01(\x08R\x0bignoreEmpty\"\xb1\x01\n\x0b\x44oubleRules\x12\x14\n\x05\x63onst\x18\x01 \x01(\x01R\x05\x63onst\x12\x0e\n\x02lt\x18\x02 \x01(\x01R\x02lt\x12\x10\n\x03lte\x18\x03 \x01(\x01R\x03lte\x12\x0e\n\x02gt\x18\x04 \x01(\x01R\x02gt\x12\x10\n\x03gte\x18\x05 \x01(\x01R\x03gte\x12\x0e\n\x02in\x18\x06 \x03(\x01R\x02in\x12\x15\n\x06not_in\x18\x07 \x03(\x01R\x05notIn\x12!\n\x0cignore_empty\x18\x08 \x01(\x08R\x0bignoreEmpty\"\xb0\x01\n\nInt32Rules\x12\x14\n\x05\x63onst\x18\x01 \x01(\x05R\x05\x63onst\x12\x0e\n\x02lt\x18\x02 \x01(\x05R\x02lt\x12\x10\n\x03lte\x18\x03 \x01(\x05R\x03lte\x12\x0e\n\x02gt\x18\x04 \x01(\x05R\x02gt\x12\x10\n\x03gte\x18\x05 \x01(\x05R\x03gte\x12\x0e\n\x02in\x18\x06 \x03(\x05R\x02in\x12\x15\n\x06not_in\x18\x07 \x03(\x05R\x05notIn\x12!\n\x0cignore_empty\x18\x08 \x01(\x08R\x0bignoreEmpty\"\xb0\x01\n\nInt64Rules\x12\x14\n\x05\x63onst\x18\x01 \x01(\x03R\x05\x63onst\x12\x0e\n\x02lt\x18\x02 \x01(\x03R\x02lt\x12\x10\n\x03lte\x18\x03 \x01(\x03R\x03lte\x12\x0e\n\x02gt\x18\x04 \x01(\x03R\x02gt\x12\x10\n\x03gte\x18\x05 \x01(\x03R\x03gte\x12\x0e\n\x02in\x18\x06 \x03(\x03R\x02in\x12\x15\n\x06not_in\x18\x07 \x03(\x03R\x05notIn\x12!\n\x0cignore_empty\x18\x08 \x01(\x08R\x0bignoreEmpty\"\xb1\x01\n\x0bUInt32Rules\x12\x14\n\x05\x63onst\x18\x01 \x01(\rR\x05\x63onst\x12\x0e\n\x02lt\x18\x02 \x01(\rR\x02lt\x12\x10\n\x03lte\x18\x03 \x01(\rR\x03lte\x12\x0e\n\x02gt\x18\x04 \x01(\rR\x02gt\x12\x10\n\x03gte\x18\x05 \x01(\rR\x03gte\x12\x0e\n\x02in\x18\x06 \x03(\rR\x02in\x12\x15\n\x06not_in\x18\x07 \x03(\rR\x05notIn\x12!\n\x0cignore_empty\x18\x08 \x01(\x08R\x0bignoreEmpty\"\xb1\x01\n\x0bUInt64Rules\x12\x14\n\x05\x63onst\x18\x01 \x01(\x04R\x05\x63onst\x12\x0e\n\x02lt\x18\x02 \x01(\x04R\x02lt\x12\x10\n\x03lte\x18\x03 \x01(\x04R\x03lte\x12\x0e\n\x02gt\x18\x04 \x01(\x04R\x02gt\x12\x10\n\x03gte\x18\x05 \x01(\x04R\x03gte\x12\x0e\n\x02in\x18\x06 \x03(\x04R\x02in\x12\x15\n\x06not_in\x18\x07 \x03(\x04R\x05notIn\x12!\n\x0cignore_empty\x18\x08 \x01(\x08R\x0bignoreEmpty\"\xb1\x01\n\x0bSInt32Rules\x12\x14\n\x05\x63onst\x18\x01 \x01(\x11R\x05\x63onst\x12\x0e\n\x02lt\x18\x02 \x01(\x11R\x02lt\x12\x10\n\x03lte\x18\x03 \x01(\x11R\x03lte\x12\x0e\n\x02gt\x18\x04 \x01(\x11R\x02gt\x12\x10\n\x03gte\x18\x05 \x01(\x11R\x03gte\x12\x0e\n\x02in\x18\x06 \x03(\x11R\x02in\x12\x15\n\x06not_in\x18\x07 \x03(\x11R\x05notIn\x12!\n\x0cignore_empty\x18\x08 \x01(\x08R\x0bignoreEmpty\"\xb1\x01\n\x0bSInt64Rules\x12\x14\n\x05\x63onst\x18\x01 \x01(\x12R\x05\x63onst\x12\x0e\n\x02lt\x18\x02 \x01(\x12R\x02lt\x12\x10\n\x03lte\x18\x03 \x01(\x12R\x03lte\x12\x0e\n\x02gt\x18\x04 \x01(\x12R\x02gt\x12\x10\n\x03gte\x18\x05 \x01(\x12R\x03gte\x12\x0e\n\x02in\x18\x06 \x03(\x12R\x02in\x12\x15\n\x06not_in\x18\x07 \x03(\x12R\x05notIn\x12!\n\x0cignore_empty\x18\x08 \x01(\x08R\x0bignoreEmpty\"\xb2\x01\n\x0c\x46ixed32Rules\x12\x14\n\x05\x63onst\x18\x01 \x01(\x07R\x05\x63onst\x12\x0e\n\x02lt\x18\x02 \x01(\x07R\x02lt\x12\x10\n\x03lte\x18\x03 \x01(\x07R\x03lte\x12\x0e\n\x02gt\x18\x04 \x01(\x07R\x02gt\x12\x10\n\x03gte\x18\x05 \x01(\x07R\x03gte\x12\x0e\n\x02in\x18\x06 \x03(\x07R\x02in\x12\x15\n\x06not_in\x18\x07 \x03(\x07R\x05notIn\x12!\n\x0cignore_empty\x18\x08 \x01(\x08R\x0bignoreEmpty\"\xb2\x01\n\x0c\x46ixed64Rules\x12\x14\n\x05\x63onst\x18\x01 \x01(\x06R\x05\x63onst\x12\x0e\n\x02lt\x18\x02 \x01(\x06R\x02lt\x12\x10\n\x03lte\x18\x03 \x01(\x06R\x03lte\x12\x0e\n\x02gt\x18\x04 \x01(\x06R\x02gt\x12\x10\n\x03gte\x18\x05 \x01(\x06R\x03gte\x12\x0e\n\x02in\x18\x06 \x03(\x06R\x02in\x12\x15\n\x06not_in\x18\x07 \x03(\x06R\x05notIn\x12!\n\x0cignore_empty\x18\x08 \x01(\x08R\x0bignoreEmpty\"\xb3\x01\n\rSFixed32Rules\x12\x14\n\x05\x63onst\x18\x01 \x01(\x0fR\x05\x63onst\x12\x0e\n\x02lt\x18\x02 \x01(\x0fR\x02lt\x12\x10\n\x03lte\x18\x03 \x01(\x0fR\x03lte\x12\x0e\n\x02gt\x18\x04 \x01(\x0fR\x02gt\x12\x10\n\x03gte\x18\x05 \x01(\x0fR\x03gte\x12\x0e\n\x02in\x18\x06 \x03(\x0fR\x02in\x12\x15\n\x06not_in\x18\x07 \x03(\x0fR\x05notIn\x12!\n\x0cignore_empty\x18\x08 \x01(\x08R\x0bignoreEmpty\"\xb3\x01\n\rSFixed64Rules\x12\x14\n\x05\x63onst\x18\x01 \x01(\x10R\x05\x63onst\x12\x0e\n\x02lt\x18\x02 \x01(\x10R\x02lt\x12\x10\n\x03lte\x18\x03 \x01(\x10R\x03lte\x12\x0e\n\x02gt\x18\x04 \x01(\x10R\x02gt\x12\x10\n\x03gte\x18\x05 \x01(\x10R\x03gte\x12\x0e\n\x02in\x18\x06 \x03(\x10R\x02in\x12\x15\n\x06not_in\x18\x07 \x03(\x10R\x05notIn\x12!\n\x0cignore_empty\x18\x08 \x01(\x08R\x0bignoreEmpty\"!\n\tBoolRules\x12\x14\n\x05\x63onst\x18\x01 \x01(\x08R\x05\x63onst\"\xd7\x05\n\x0bStringRules\x12\x14\n\x05\x63onst\x18\x01 \x01(\tR\x05\x63onst\x12\x10\n\x03len\x18\x13 \x01(\x04R\x03len\x12\x17\n\x07min_len\x18\x02 \x01(\x04R\x06minLen\x12\x17\n\x07max_len\x18\x03 \x01(\x04R\x06maxLen\x12\x1b\n\tlen_bytes\x18\x14 \x01(\x04R\x08lenBytes\x12\x1b\n\tmin_bytes\x18\x04 \x01(\x04R\x08minBytes\x12\x1b\n\tmax_bytes\x18\x05 \x01(\x04R\x08maxBytes\x12\x18\n\x07pattern\x18\x06 \x01(\tR\x07pattern\x12\x16\n\x06prefix\x18\x07 \x01(\tR\x06prefix\x12\x16\n\x06suffix\x18\x08 \x01(\tR\x06suffix\x12\x1a\n\x08\x63ontains\x18\t \x01(\tR\x08\x63ontains\x12!\n\x0cnot_contains\x18\x17 \x01(\tR\x0bnotContains\x12\x0e\n\x02in\x18\n \x03(\tR\x02in\x12\x15\n\x06not_in\x18\x0b \x03(\tR\x05notIn\x12\x16\n\x05\x65mail\x18\x0c \x01(\x08H\x00R\x05\x65mail\x12\x1c\n\x08hostname\x18\r \x01(\x08H\x00R\x08hostname\x12\x10\n\x02ip\x18\x0e \x01(\x08H\x00R\x02ip\x12\x14\n\x04ipv4\x18\x0f \x01(\x08H\x00R\x04ipv4\x12\x14\n\x04ipv6\x18\x10 \x01(\x08H\x00R\x04ipv6\x12\x12\n\x03uri\x18\x11 \x01(\x08H\x00R\x03uri\x12\x19\n\x07uri_ref\x18\x12 \x01(\x08H\x00R\x06uriRef\x12\x1a\n\x07\x61\x64\x64ress\x18\x15 \x01(\x08H\x00R\x07\x61\x64\x64ress\x12\x14\n\x04uuid\x18\x16 \x01(\x08H\x00R\x04uuid\x12\x43\n\x10well_known_regex\x18\x18 \x01(\x0e\x32\x17.validate.v1.KnownRegexH\x00R\x0ewellKnownRegex\x12\x1c\n\x06strict\x18\x19 \x01(\x08:\x04trueR\x06strict\x12!\n\x0cignore_empty\x18\x1a \x01(\x08R\x0bignoreEmptyB\x0c\n\nwell_known\"\xe2\x02\n\nBytesRules\x12\x14\n\x05\x63onst\x18\x01 \x01(\x0cR\x05\x63onst\x12\x10\n\x03len\x18\r \x01(\x04R\x03len\x12\x17\n\x07min_len\x18\x02 \x01(\x04R\x06minLen\x12\x17\n\x07max_len\x18\x03 \x01(\x04R\x06maxLen\x12\x18\n\x07pattern\x18\x04 \x01(\tR\x07pattern\x12\x16\n\x06prefix\x18\x05 \x01(\x0cR\x06prefix\x12\x16\n\x06suffix\x18\x06 \x01(\x0cR\x06suffix\x12\x1a\n\x08\x63ontains\x18\x07 \x01(\x0cR\x08\x63ontains\x12\x0e\n\x02in\x18\x08 \x03(\x0cR\x02in\x12\x15\n\x06not_in\x18\t \x03(\x0cR\x05notIn\x12\x10\n\x02ip\x18\n \x01(\x08H\x00R\x02ip\x12\x14\n\x04ipv4\x18\x0b \x01(\x08H\x00R\x04ipv4\x12\x14\n\x04ipv6\x18\x0c \x01(\x08H\x00R\x04ipv6\x12!\n\x0cignore_empty\x18\x0e \x01(\x08R\x0bignoreEmptyB\x0c\n\nwell_known\"k\n\tEnumRules\x12\x14\n\x05\x63onst\x18\x01 \x01(\x05R\x05\x63onst\x12!\n\x0c\x64\x65\x66ined_only\x18\x02 \x01(\x08R\x0b\x64\x65\x66inedOnly\x12\x0e\n\x02in\x18\x03 \x03(\x05R\x02in\x12\x15\n\x06not_in\x18\x04 \x03(\x05R\x05notIn\">\n\x0cMessageRules\x12\x12\n\x04skip\x18\x01 \x01(\x08R\x04skip\x12\x1a\n\x08required\x18\x02 \x01(\x08R\x08required\"\xb3\x01\n\rRepeatedRules\x12\x1b\n\tmin_items\x18\x01 \x01(\x04R\x08minItems\x12\x1b\n\tmax_items\x18\x02 \x01(\x04R\x08maxItems\x12\x16\n\x06unique\x18\x03 \x01(\x08R\x06unique\x12-\n\x05items\x18\x04 \x01(\x0b\x32\x17.validate.v1.FieldRulesR\x05items\x12!\n\x0cignore_empty\x18\x05 \x01(\x08R\x0bignoreEmpty\"\xe2\x01\n\x08MapRules\x12\x1b\n\tmin_pairs\x18\x01 \x01(\x04R\x08minPairs\x12\x1b\n\tmax_pairs\x18\x02 \x01(\x04R\x08maxPairs\x12\x1b\n\tno_sparse\x18\x03 \x01(\x08R\x08noSparse\x12+\n\x04keys\x18\x04 \x01(\x0b\x32\x17.validate.v1.FieldRulesR\x04keys\x12/\n\x06values\x18\x05 \x01(\x0b\x32\x17.validate.v1.FieldRulesR\x06values\x12!\n\x0cignore_empty\x18\x06 \x01(\x08R\x0bignoreEmpty\"M\n\x08\x41nyRules\x12\x1a\n\x08required\x18\x01 \x01(\x08R\x08required\x12\x0e\n\x02in\x18\x02 \x03(\tR\x02in\x12\x15\n\x06not_in\x18\x03 \x03(\tR\x05notIn\"\xe9\x02\n\rDurationRules\x12\x1a\n\x08required\x18\x01 \x01(\x08R\x08required\x12/\n\x05\x63onst\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63onst\x12)\n\x02lt\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x02lt\x12+\n\x03lte\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x03lte\x12)\n\x02gt\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x02gt\x12+\n\x03gte\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x03gte\x12)\n\x02in\x18\x07 \x03(\x0b\x32\x19.google.protobuf.DurationR\x02in\x12\x30\n\x06not_in\x18\x08 \x03(\x0b\x32\x19.google.protobuf.DurationR\x05notIn\"\xf3\x02\n\x0eTimestampRules\x12\x1a\n\x08required\x18\x01 \x01(\x08R\x08required\x12\x30\n\x05\x63onst\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x05\x63onst\x12*\n\x02lt\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02lt\x12,\n\x03lte\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x03lte\x12*\n\x02gt\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02gt\x12,\n\x03gte\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x03gte\x12\x15\n\x06lt_now\x18\x07 \x01(\x08R\x05ltNow\x12\x15\n\x06gt_now\x18\x08 \x01(\x08R\x05gtNow\x12\x31\n\x06within\x18\t \x01(\x0b\x32\x19.google.protobuf.DurationR\x06within*v\n\nKnownRegex\x12#\n\x1fKNOWN_REGEX_UNKNOWN_UNSPECIFIED\x10\x00\x12 \n\x1cKNOWN_REGEX_HTTP_HEADER_NAME\x10\x01\x12!\n\x1dKNOWN_REGEX_HTTP_HEADER_VALUE\x10\x02:<\n\x08\x64isabled\x12\x1f.google.protobuf.MessageOptions\x18\xaf\x08 \x01(\x08R\x08\x64isabled::\n\x07ignored\x12\x1f.google.protobuf.MessageOptions\x18\xb0\x08 \x01(\x08R\x07ignored::\n\x08required\x12\x1d.google.protobuf.OneofOptions\x18\xaf\x08 \x01(\x08R\x08required:M\n\x05rules\x12\x1d.google.protobuf.FieldOptions\x18\xaf\x08 \x01(\x0b\x32\x17.validate.v1.FieldRulesR\x05rulesB\xa1\x01\n\x0f\x63om.validate.v1B\rValidateProtoP\x01Z2github.com/envoyproxy/protoc-gen-validate/validate\xa2\x02\x03VXX\xaa\x02\x0bValidate.V1\xca\x02\x0bValidate\\V1\xe2\x02\x17Validate\\V1\\GPBMetadata\xea\x02\x0cValidate::V1')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'validate.v1.validate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.validate.v1B\rValidateProtoP\001Z2github.com/envoyproxy/protoc-gen-validate/validate\242\002\003VXX\252\002\013Validate.V1\312\002\013Validate\\V1\342\002\027Validate\\V1\\GPBMetadata\352\002\014Validate::V1'
  _globals['_KNOWNREGEX']._serialized_start=5993
  _globals['_KNOWNREGEX']._serialized_end=6111
  _globals['_FIELDRULES']._serialized_start=143
  _globals['_FIELDRULES']._serialized_end=1305
  _globals['_FLOATRULES']._serialized_start=1308
  _globals['_FLOATRULES']._serialized_end=1484
  _globals['_DOUBLERULES']._serialized_start=1487
  _globals['_DOUBLERULES']._serialized_end=1664
  _globals['_INT32RULES']._serialized_start=1667
  _globals['_INT32RULES']._serialized_end=1843
  _globals['_INT64RULES']._serialized_start=1846
  _globals['_INT64RULES']._serialized_end=2022
  _globals['_UINT32RULES']._serialized_start=2025
  _globals['_UINT32RULES']._serialized_end=2202
  _globals['_UINT64RULES']._serialized_start=2205
  _globals['_UINT64RULES']._serialized_end=2382
  _globals['_SINT32RULES']._serialized_start=2385
  _globals['_SINT32RULES']._serialized_end=2562
  _globals['_SINT64RULES']._serialized_start=2565
  _globals['_SINT64RULES']._serialized_end=2742
  _globals['_FIXED32RULES']._serialized_start=2745
  _globals['_FIXED32RULES']._serialized_end=2923
  _globals['_FIXED64RULES']._serialized_start=2926
  _globals['_FIXED64RULES']._serialized_end=3104
  _globals['_SFIXED32RULES']._serialized_start=3107
  _globals['_SFIXED32RULES']._serialized_end=3286
  _globals['_SFIXED64RULES']._serialized_start=3289
  _globals['_SFIXED64RULES']._serialized_end=3468
  _globals['_BOOLRULES']._serialized_start=3470
  _globals['_BOOLRULES']._serialized_end=3503
  _globals['_STRINGRULES']._serialized_start=3506
  _globals['_STRINGRULES']._serialized_end=4233
  _globals['_BYTESRULES']._serialized_start=4236
  _globals['_BYTESRULES']._serialized_end=4590
  _globals['_ENUMRULES']._serialized_start=4592
  _globals['_ENUMRULES']._serialized_end=4699
  _globals['_MESSAGERULES']._serialized_start=4701
  _globals['_MESSAGERULES']._serialized_end=4763
  _globals['_REPEATEDRULES']._serialized_start=4766
  _globals['_REPEATEDRULES']._serialized_end=4945
  _globals['_MAPRULES']._serialized_start=4948
  _globals['_MAPRULES']._serialized_end=5174
  _globals['_ANYRULES']._serialized_start=5176
  _globals['_ANYRULES']._serialized_end=5253
  _globals['_DURATIONRULES']._serialized_start=5256
  _globals['_DURATIONRULES']._serialized_end=5617
  _globals['_TIMESTAMPRULES']._serialized_start=5620
  _globals['_TIMESTAMPRULES']._serialized_end=5991
# @@protoc_insertion_point(module_scope)



import grpc


from .gen.admin.v1.integration_incident_pb2 import (
	DeleteIncidentAccountByIdRequest,
	DeleteIncidentAccountByIdResponse,
	ConnectIncidentAccountRequest,
	ConnectIncidentAccountResponse,
	GetIncidentAccountsRequest,
	GetIncidentAccountsResponse,
	GetIncidentAccountByIdRequest,
	GetIncidentAccountByIdResponse,
)

from .gen.admin.v1.integration_incident_pb2_grpc import IncidentServiceStub
class IncidentService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = IncidentServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def ConnectIncidentAccount(self, request: ConnectIncidentAccountRequest) -> ConnectIncidentAccountResponse:
		return self.stub.ConnectIncidentAccount(request, metadata=self.headers)

	def GetIncidentAccounts(self, request: GetIncidentAccountsRequest) -> GetIncidentAccountsResponse:
		return self.stub.GetIncidentAccounts(request, metadata=self.headers)

	def GetIncidentAccountById(self, request: GetIncidentAccountByIdRequest) -> GetIncidentAccountByIdResponse:
		return self.stub.GetIncidentAccountById(request, metadata=self.headers)

	def DeleteIncidentAccountById(self, request: DeleteIncidentAccountByIdRequest) -> DeleteIncidentAccountByIdResponse:
		return self.stub.DeleteIncidentAccountById(request, metadata=self.headers)




import grpc


from .gen.admin.v1.satellite_pb2 import (
	CreateSatelliteRequest,
	CreateSatelliteResponse,
	GetSatelliteByIdRequest,
	GetSatelliteByIdResponse,
	GetSatellitesRequest,
	GetSatellitesResponse,
	GetSatelliteApiKeyRequest,
	GetSatelliteApiKeyResponse,
	DeleteSatelliteRequest,
	DeleteSatelliteResponse,
)

from .gen.admin.v1.satellite_pb2_grpc import SatelliteServiceStub
class SatelliteService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = SatelliteServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def CreateSatellite(self, request: CreateSatelliteRequest) -> CreateSatelliteResponse:
		return self.stub.CreateSatellite(request, metadata=self.headers)

	def GetSatelliteById(self, request: GetSatelliteByIdRequest) -> GetSatelliteByIdResponse:
		return self.stub.GetSatelliteById(request, metadata=self.headers)

	def GetSatellites(self, request: GetSatellitesRequest) -> GetSatellitesResponse:
		return self.stub.GetSatellites(request, metadata=self.headers)

	def GetSatelliteApiKey(self, request: GetSatelliteApiKeyRequest) -> GetSatelliteApiKeyResponse:
		return self.stub.GetSatelliteApiKey(request, metadata=self.headers)

	def DeleteSatellite(self, request: DeleteSatelliteRequest) -> DeleteSatelliteResponse:
		return self.stub.DeleteSatellite(request, metadata=self.headers)

